Module config

Module config 

Configuration loading and profile YAML parsing. Configuration and profile-file parsing.

PrismTTY accepts ChromaTerm-style YAML rule files and native profile files that add profile metadata such as inheritance and detection hints.

Structs

LoadedProfileFile
Parsed native profile file, including metadata and rules.
PrismConfig
Fully resolved highlighting configuration.
ProfileMetaDoc
Metadata declared in a native profile YAML file.
RuleSpec
One highlight rule before PCRE2 compilation.

Enums

CaptureRef
Capture group reference used by capture-specific styles.
ConfigError
Errors returned while loading, parsing, or resolving PrismTTY configuration.
RuleStyle
Style target for a highlight rule.

Constants

RESERVED_PROFILE_RUNTIME_MESSAGE
Error message returned when user profile files include reserved runtime metadata.

Functions

load_profile_file
Reads and parses a native PrismTTY profile YAML file.
parse_profile_yaml
Parses native PrismTTY profile YAML from a string.