Configuration loading and profile YAML parsing. Configuration and profile-file parsing.
PrismTTY accepts ChromaTerm-style YAML rule files and native profile files that add profile metadata such as inheritance and detection hints.
Structs
- Loaded
Profile File - Parsed native profile file, including metadata and rules.
- Prism
Config - Fully resolved highlighting configuration.
- Profile
Meta Doc - Metadata declared in a native profile YAML file.
- Rule
Spec - One highlight rule before PCRE2 compilation.
Enums
- Capture
Ref - Capture group reference used by capture-specific styles.
- Config
Error - Errors returned while loading, parsing, or resolving PrismTTY configuration.
- Rule
Style - Style target for a highlight rule.
Constants
- RESERVED_
PROFILE_ RUNTIME_ MESSAGE - Error message returned when user profile files include reserved runtime metadata.
Functions
- load_
profile_ file - Reads and parses a native PrismTTY profile YAML file.
- parse_
profile_ yaml - Parses native PrismTTY profile YAML from a string.